@@ -155,11 +155,17 @@ static gboolean
 caja_python_init_python (void)
 {
 	PyObject *caja;
+	GModule *libpython;
 	char *argv[] = { "caja", NULL };
 
 	if (Py_IsInitialized())
 		return TRUE;
 
+  	debug("g_module_open " PY_LIB_LOC "/libpython" PYTHON_VERSION "." G_MODULE_SUFFIX ".1.0");
+	libpython = g_module_open(PY_LIB_LOC "/libpython" PYTHON_VERSION "." G_MODULE_SUFFIX ".1.0", 0);
+	if (!libpython)
+		g_warning("g_module_open libpython failed: %s", g_module_error());
+
 	debug("Py_Initialize");
 	Py_Initialize();
 	if (PyErr_Occurred())
